FieldValidator<T> class abstract

A validator that validates a single field.

Inheritance
Implementers

Constructors

FieldValidator({required String errorCode, String? message})
Creates a Validator.
const

Properties

errorCode String
The error code to display if the validation fails.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
The error message to display if the validation fails.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator FieldValidatorFn<T>
The validator function.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited