MatchesValidator<T> class
Compare the value with the value of the cross field and validate if the value matches the cross field value.
- Inheritance
-
- Object
- Validator<
T> - CrossFieldValidator<
T> - MatchesValidator
Constructors
- MatchesValidator({required FieldSchema field, String? message})
-
Creates a MatchesValidator.
const
Properties
- errorCode → String
-
The error code to display if the validation fails.
finalinherited
- field → FieldSchema
-
The field to compare with.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
The error message to display if the validation fails.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validator
→ CrossFieldValidatorFn<
T> -
The validator function.
no setteroverride
Methods
-
assertValueIsOfType(
BuildContext context) → void -
Asserts that the value is of the correct type.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited